package com.bwie.controller;


import com.bwie.common.domain.Education;
import com.bwie.common.domain.History;
import com.bwie.common.domain.Patient;
import com.bwie.common.domain.Pressure;
import com.bwie.common.domain.Records;
import com.bwie.common.domain.Sugar;
import com.bwie.common.domain.request.HistoryRequest;
import com.bwie.common.domain.request.UserLevel;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.service.ListsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @version: java version 1.8
 * @author: liguangyao
 * @date: 2023-12-10 上午 9:35
 */
@RestController
public class ListsController {
    @Autowired
    private ListsService listsService;

    /**
     * 功能描述
     * 健康列表
     * @author liguangyao
     * @Date 2023/12/10
     * @param
     * @return
     */
    @GetMapping("/educationList")
    public Result<List<Education>> educationList(){
        Result<List<Education>> result = listsService.educationList();
        return result;
    }
    //以下的功能是根据登录人进行查看各自只能看各自的管理员登录查看所有并且可以操作
    /**
     * 功能描述
     * 过往病史列表History
     * @author liguangyao
     * @Date 2023/12/10
     * @param historyRequest
     * @return
     */
    @PostMapping("/historyList")
    public Result<PageResult<History>> historyList(@RequestBody HistoryRequest historyRequest){
        Result<PageResult<History>> result = listsService.historyList(historyRequest);
        return result;
    }
    /**
     * 功能描述
     * 糖尿病管理列表Patient只能管理员进行查看
     * @author liguangyao
     * @Date 2023/12/10
     * @param
     * @return
     */
    @PostMapping("/patientList")
    public Result<PageResult<Patient>> patientList(@RequestBody UserLevel userLevel){
        Result<PageResult<Patient>> result = listsService.patientList(userLevel);
        return result;
    }
    /**
     * 功能描述
     * 血压数据列表Pressure
     * @author liguangyao
     * @Date 2023/12/10
     * @param userLevel
     * @return
     */
    @PostMapping("/pressureList")
    public Result<PageResult<Pressure>> pressureList(@RequestBody UserLevel userLevel){
        Result<PageResult<Pressure>> result = listsService.pressureList(userLevel);
        return result;
    }
    /**
     * 功能描述
     * 健康档案表Records
     * @author liguangyao
     * @Date 2023/12/10
     * @param userLevel
     * @return
     */
    @PostMapping("/recordsList")
    public Result<PageResult<Records>> recordsList(@RequestBody UserLevel userLevel){
        Result<PageResult<Records>> result = listsService.recordsList(userLevel);
        return result;
    }
    /**
     * 功能描述
     * 血糖表Sugar
     * @author liguangyao
     * @Date 2023/12/10
     * @param userLevel
     * @return
     */
    @PostMapping("/sugarList")
    public Result<PageResult<Sugar>> sugarList(@RequestBody UserLevel userLevel){
        Result<PageResult<Sugar>> result = listsService.sugarList(userLevel);
        return result;
    }

}
