package com.bwie.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.Admin;
import com.bwie.common.domain.Education;
import com.bwie.common.domain.History;
import com.bwie.common.domain.Patient;
import com.bwie.common.domain.Pressure;
import com.bwie.common.domain.Records;
import com.bwie.common.domain.Sugar;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.HistoryRequest;
import com.bwie.common.domain.request.UserLevel;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.mapper.ListsMapper;
import com.bwie.service.ListsService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @version: java version 1.8
 * @author: liguangyao
 * @date: 2023-12-10 上午 9:38
 */

@Service
public class ListsServiceImpl implements ListsService {
    @Autowired
    private ListsMapper listsMapper;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private HttpServletRequest request;

    //查询健康列表
    @Override
    public Result<List<Education>> educationList() {
        List<Education> list = listsMapper.educationList();
        return Result.success(list);
    }

    //查询用户病史列表
    @Override
    public Result<PageResult<History>> historyList(HistoryRequest historyRequest) {
        Result<Integer> user = getUser();
        if(user.getCode()==500){
            //用户登录超时
            return Result.error(user.getMsg());
        }
        historyRequest.setRank(user.getData());
        if(user.getData()==2){
            Integer userId = Integer.valueOf(user.getMsg());
            historyRequest.setUserId(userId);
        }
        PageHelper.startPage(historyRequest.getPageNum(),historyRequest.getPageSize());
        List<History> list = listsMapper.historyList(historyRequest);
        PageInfo<History> info = new PageInfo<>(list);
        return PageResult.toResult(info.getTotal(),list);
    }

    //糖尿病管理
    @Override
    public Result<PageResult<Patient>> patientList(UserLevel userLevel) {
        Result<Integer> user = getUser();
        //判断用户是否登录token
        if(user.getCode()==500){
            //用户登录超时
            return Result.error(user.getMsg());
        }
        userLevel.setRank(user.getData());
        //判断是用户登录还是管理员登录用户登录2 管理员登录1
        if(user.getData()==2){
            Integer userId = Integer.valueOf(user.getMsg());
            userLevel.setUserId(userId);
        }
        //列表查询
        PageHelper.startPage(userLevel.getPageNum(),userLevel.getPageSize());
        List<Patient> list = listsMapper.patientList(userLevel);
        PageInfo<Patient> info = new PageInfo<>(list);

        return PageResult.toResult(info.getTotal(),list);
    }

    //用户血压表
    @Override
    public Result<PageResult<Pressure>> pressureList(UserLevel userLevel) {
        Result<Integer> user = getUser();
        //判断用户是否登录token
        if(user.getCode()==500){
            //用户登录超时
            return Result.error(user.getMsg());
        }
        userLevel.setRank(user.getData());
        //判断是用户登录还是管理员登录用户登录2 管理员登录1
        if(user.getData()==2){
            Integer userId = Integer.valueOf(user.getMsg());
            userLevel.setUserId(userId);
        }
        PageHelper.startPage(userLevel.getPageNum(),userLevel.getPageSize());
        List<Pressure> list = listsMapper.pressureList(userLevel);
        PageInfo<Pressure> info = new PageInfo<>(list);
        return PageResult.toResult(info.getTotal(),list);
    }

    //用户健康档案列表
    @Override
    public Result<PageResult<Records>> recordsList(UserLevel userLevel) {
        Result<Integer> user = getUser();
        //判断用户是否登录token
        if(user.getCode()==500){
            //用户登录超时
            return Result.error(user.getMsg());
        }
        userLevel.setRank(user.getData());
        //判断是用户登录还是管理员登录用户登录2 管理员登录1
        if(user.getData()==2){
            Integer userId = Integer.valueOf(user.getMsg());
            userLevel.setUserId(userId);
        }
        PageHelper.startPage(userLevel.getPageNum(),userLevel.getPageSize());
        List<Records> list = listsMapper.recordsList(userLevel);
        PageInfo<Records> info = new PageInfo<>(list);
        return PageResult.toResult(info.getTotal(),list);
    }

    //用户血糖列表
    @Override
    public Result<PageResult<Sugar>> sugarList(UserLevel userLevel) {
        Result<Integer> user = getUser();
        //判断用户是否登录token
        if(user.getCode()==500){
            //用户登录超时
            return Result.error(user.getMsg());
        }
        userLevel.setRank(user.getData());
        //判断是用户登录还是管理员登录用户登录2 管理员登录1
        if(user.getData()==2){
            Integer userId = Integer.valueOf(user.getMsg());
            userLevel.setUserId(userId);
        }
        PageHelper.startPage(userLevel.getPageNum(),userLevel.getPageSize());
        List<Sugar> list = listsMapper.sugarList(userLevel);
        PageInfo<Sugar> info = new PageInfo<>(list);
        return PageResult.toResult(info.getTotal(),list);
    }

    //获取用户登录值
    private Result<Integer> getUser(){
        String token = request.getHeader("token");
        if(token==null){
            return Result.error("用户登录超时请重新登录");
        }
        String s = redisTemplate.opsForValue().get(JwtConstants.USER_KEY + token);

        User user = JSON.parseObject(s, User.class);

        String name = user.getUsername();
        Integer num = listsMapper.getUser(name);
        if (num!=null){
            if(user!=null){
                return Result.success(2,String.valueOf(user.getUserId()));
            }
        }
        Admin admin = JSON.parseObject(s,Admin.class);
        if(admin!=null){
            return Result.success(1);
        }
        return Result.error("用户登录超时请重新登录");
    }
}
